[![Build Status](https://travis-ci.org/ModellingWebLab/cellmlmanip.svg?branch=develop)](https://travis-ci.com/ModellingWebLab/cellmlmanip) [![Documentation Status](https://readthedocs.org/projects/cellmlmanip/badge/?version=latest)](https://cellmlmanip.readthedocs.io/en/latest/?badge=latest) [![Coverage Status](https://codecov.io/gh/ModellingWebLab/cellmlmanip/branch/develop/graph/badge.svg)](https://codecov.io/gh/ModellingWebLab/cellmlmanip/)

# cellmlmanip
CellML loading and model equation manipulation library

## Installing 
We recommend installing cellmlmanip in a virtual environment (e.g. using conda or pipenv or virtualenv).

Users install `cellmlmanip` using pip.

```
pip install cellmlmanip
```

Cellmlmanip is tested and developed on Python 3.5 and higher.

## Release notes
For release notes see [RELEASE.md](./RELEASE.md)


## Documentation
API documentation explaining how to use cellmlmanip can be found on [readthedocs](https://cellmlmanip.readthedocs.io/en/latest)

## Contributing
For developer instructions, see [CONTRIBUTING.md](./CONTRIBUTING.md)
